/**
 * ${jpp:disclaimer}
 *
 * ${jpp:copyright}
**/
package com.inet.cowork.gptbot.structure;

import com.inet.config.ConfigKey;
import com.inet.config.structure.model.*;
import com.inet.config.structure.provider.AbstractStructureProvider;
import com.inet.config.structure.provider.ConfigStructureSettings;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.net.URL;
import java.util.ArrayList;
import java.util.Set;

/**
 * provides configuration properties to this plugin that will show up in the Configuration
 * module
 */
public class CoWorkGPTBotStructureProvider extends AbstractStructureProvider {
    public static final ConfigKey OPENAI_KEY     = new ConfigKey( "cowork.gpt.bot.openaikey", "", String.class );
    public static final ConfigKey OPENAI_SYSTEM_PROMPT     = new ConfigKey( "cowork.gpt.bot.openaisystemprompt", "You are a helpful assistant that will do its best to fulfill the user request.", String.class );

    private static final String CATEGORY_GPT_BOT     = "cowork.gpt.bot";
    private static final String GPT_BOT_SETTINGS = "cowork.gpt.bot.settings";
    /** {@inheritDoc} */
    @Override
    public void addGroupsTo( @Nonnull Set<ConfigGroup> groups, boolean advanced, @Nonnull ConfigStructureSettings settings ) {

    }

    /** {@inheritDoc} */
    @Override
    public void addCategoriesTo( @Nonnull Set<ConfigCategory> categories, @Nonnull String groupKey, boolean advanced,
                                 @Nonnull ConfigStructureSettings settings ) {
        if (groupKey.equals( CATEGORY_GROUP_COMMUNICATION )) {
            categories.add( new ConfigCategory(199,CATEGORY_GPT_BOT, "CoWork GPT","cowork.gpt.bot") );
        }

    }

    /** {@inheritDoc} */
    @Override
    public URL getCategoryIcon( @Nonnull String categoryKey ) {
        if (CATEGORY_GPT_BOT.equals( categoryKey )) {
            return getClass().getResource( "/com/inet/cowork/gptbot/cowork_openai_48.png" );
        }
        return null;
    }

    /** {@inheritDoc} */
    @Override
    public void addPropertyGroupsTo( @Nonnull Set<ConfigPropertyGroup> configPropertyGroups, @Nonnull String categoryKey, boolean advanced,
                                     @Nonnull ConfigStructureSettings settings ) {
        switch( categoryKey ) {
            case CATEGORY_GPT_BOT:
                configPropertyGroups.add( new ConfigPropertyGroup( 100, GPT_BOT_SETTINGS ) );
                break;
        }
    }

    /** {@inheritDoc} */
    @Override
    public void addPropertiesTo( @Nonnull Set<ConfigProperty> configProperties, @Nonnull String propertyGroupKey, boolean advanced,
                                 @Nonnull ConfigStructureSettings settings ) {
        if (GPT_BOT_SETTINGS.equals( propertyGroupKey )) {
            addTo(configProperties,OPENAI_KEY,settings );
            addTo(configProperties,OPENAI_SYSTEM_PROMPT,settings );
        }
    }

    /** {@inheritDoc} */
    @Override
    public void validate( @Nullable String categoryKey, @Nonnull ArrayList<ConfigValidationMsg> messages,
                          @Nonnull ArrayList<ConfigConditionAction> conditions, @Nonnull ConfigStructureSettings settings ) {

    }
}
